@@ -1,5 +1,5 @@
 package Date::Manip::Lang::english;
-# Copyright (c) 1995-2010 Sullivan Beck. All rights reserved.
+# Copyright (c) 1995-2011 Sullivan Beck. All rights reserved.
 # This program is free software; you can redistribute it and/or modify it
 # under the same terms as Perl itself.
 
@@ -26,10 +26,10 @@ use YAML::Syck;
 use strict;
 use warnings;
 
-use vars qw($VERSION);
-$VERSION='6.20';
+our($VERSION);
+$VERSION='6.25';
 
-use vars qw($Language @Encodings);
+our($Language,@Encodings);
 @Encodings = qw();
 
 my @in    = <DATA>;
